@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-''' 
+""" 
 
 Base Device
 
@@ -10,23 +10,24 @@ device_type = switch,dimmer,contact,...
 
 having a common device types eliminates the need to know the underlying technology being used
 
-'''
+"""
 
 
-from ... item_base import Item_Base
+from ...item_base import Item_Base
 
 
 class Device_Base(Item_Base):
-
     def __init__(self, container, device_type, name, address):
-        Item_Base.__init__(self,container, name)
+        Item_Base.__init__(self, container, name)
 
         self.device_type = device_type
         self.address = address
 
     def __str__(self):
-        return ('Device {}, type {}, ID {}'.format(self.name,self.device_type,self.address))
+        return "Device {}, type {}, ID {}".format(
+            self.name, self.device_type, self.address
+        )
 
     def get_identifier(self):
-        return self.address   
-        
\ No newline at end of file
+        return self.address
+
